% Testing the speed controlled system with mechanical resonance, 
% evaluating:
%            the system without any series antiresonant compensator. 
%            the system with NOTCH series compensator
%            the system with FIR filter
%
% Exploring the impact of Jmotor/Jload ration (the resonance ratio). 
%
% RUN this file, observe 5 Figures created, notice their titles on the top

Tsim = 0.00001;
Ts = 0.0003;
JM= 0.0007;
JL= 0.0007;
KK = 317;
KV = 0.15;
J = JM + JL;
KFB = 1;
KM = 1;
WNF = sqrt(KK*(JM+JL)/JM/JL);
KSIPMH = sqrt(KV*KV*(JM+JL)/4/JM/JL/KK);
KSIZMH = sqrt(KV*KV/4/JL/KK);
KP = 0.2027 * 2 * J/Ts /KM /KFB;
KI = 0.03512 * 2 * J/Ts /KM /KFB;
KP = KP/4; KI = KI/20;
KSIZ = KSIPMH;
KSIP = 0.7;
sim('nocomp.mdl');
close all; stairs(speed,'b'); hold on; stairs(torque/4+1.2,'r')
title('UNCOMPENSATED SPEED CONTROLLED SYSTEM // WITHOUT ANY ANTIRESONANT FILTER')

sim('notch.mdl');
figure; stairs(speed,'b'); hold on; stairs(torque/4+1.2,'r')
title('THE SYSTEM WITH NOTCH ANTIRESONANT FILTER')


sim('fir.mdl');
figure; stairs(speed,'b'); hold on; stairs(torque/4+1.2,'r')
title('THE SYSTEM WITH FIR ANTIRESONANT FILTER')


Delay = pi/WNF/Ts


% test uncompensated system, J/J ratio


% Here, case where JM = 50%, JL = 150% 

Tsim = 0.00001;
Ts = 0.0003;
JM= 0.0007*0.5;
JL= 0.0007*1.5;
KK = 317;
KV = 0.15;
J = JM + JL;
KFB = 1;
KM = 1;
KP = 0.2027 * 2 * J/Ts /KM /KFB;
KI = 0.03512 * 2 * J/Ts /KM /KFB;
KP = KP/4; KI = KI/20;

sim('nocomp.mdl');
figure; stairs(speed,'b'); hold on; stairs(torque/4+1.2,'r')
title('UNCOMPENSATED SPEED CONTROLLED SYSTEM, JM reduced 50%, JL INCREASED 150%')



% here reverse case, even larger ratio 

JM= 0.0007*1.7;
JL= 0.0007*0.3;
sim('nocomp.mdl');
figure; stairs(speed,'b'); hold on; stairs(torque/4+1.2,'r')
title('UNCOMPENSATED SPEED CONTROLLED SYSTEM, JL increased, JL reduced 150%')